@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::CheckPrereqsIndexed;
 # ABSTRACT: prevent a release if you have prereqs not found on CPAN
-$Dist::Zilla::Plugin::CheckPrereqsIndexed::VERSION = '0.014';
+$Dist::Zilla::Plugin::CheckPrereqsIndexed::VERSION = '0.015';
 use 5.10.0; # //
 use Moose;
 
@@ -44,6 +44,9 @@ has skips => (
   default => sub { [] },
 );
 
+my %NOT_INDEXED = map {; $_ => 1 }
+                  qw(Config DB Errno integer NEXT perl Pod::Functions);
+
 sub before_release {
   my ($self) = @_;
 
@@ -59,9 +62,7 @@ sub before_release {
   # everything -- rjbs, 2011-08-18
   for my $req_set (map { values %$_ } values %$prereqs_hash) {
     REQ_PKG: for my $pkg (keys %$req_set) {
-      next if $pkg eq 'Config'; # special case -- rjbs, 2011-05-20
-      next if $pkg eq 'perl';   # special case -- rjbs, 2011-02-05
-      next if $pkg eq 'integer';   # special case -- drolsky, 2015-01-05
+      next if $NOT_INDEXED{ $pkg };
 
       next if any { $pkg =~ $_ } @skips;
 
@@ -148,7 +149,7 @@ Dist::Zilla::Plugin::CheckPrereqsIndexed - prevent a release if you have prereqs
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 OVERVIEW
 
